How are the Neural Network Trained?
===================================

The neural network is trained with the back propagation algorithm. However, not just the weights are trained, the initial inventory is also treated as another parameter.